@@ -194,8 +194,10 @@ class Controller(api.BaseController):
 
         :raises HTTPNotFound if image metadata is not available to user
         """
+        image_meta = self.get_image_meta_or_404(req, id)
+        del image_meta['location']
         return {
-            'image_meta': self.get_image_meta_or_404(req, id),
+            'image_meta': image_meta
         }
 
     def show(self, req, id):
@@ -271,6 +273,7 @@ class Controller(api.BaseController):
                          " from store"), id)
             image_iterator = get_from_store(image)
 
+        del image['location']
         return {
             'image_iterator': image_iterator,
             'image_meta': image,
@@ -537,6 +540,10 @@ class Controller(api.BaseController):
             if location:
                 image_meta = self._activate(req, image_id, location)
 
+        # Prevent client from learning the location, as it
+        # could contain security credentials
+        image_meta.pop('location', None)
+
         return {'image_meta': image_meta}
 
     def update(self, req, id, image_meta, image_data):
@@ -582,6 +589,10 @@ class Controller(api.BaseController):
         else:
             self.notifier.info('image.update', image_meta)
 
+        # Prevent client from learning the location, as it
+        # could contain security credentials
+        image_meta.pop('location', None)
+
         return {'image_meta': image_meta}
 
     def delete(self, req, id):
