@@ -37,13 +37,98 @@ class TestBinGlance(functional.FunctionalTest):
         # NoAuth strategy.
         os.environ['OS_AUTH_STRATEGY'] = 'noauth'
 
+    def test_add_with_location(self):
+        self.cleanup()
+        self.start_servers(**self.__dict__.copy())
+
+        api_port = self.api_port
+        registry_port = self.registry_port
+
+        # 0. Verify no public images
+        cmd = "bin/glance --port=%d index" % api_port
+
+        exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        self.assertEqual('', out.strip())
+
+        # 1. Add public image
+        cmd = "bin/glance --port=%d add is_public=True"\
+              " name=MyImage location=http://example.com" % api_port
+        exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        self.assertTrue(out.strip().startswith('Added new image with ID:'))
+
+        # 2. Verify image added as public image
+        cmd = "bin/glance --port=%d index" % api_port
+
+        exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        lines = out.split("\n")[2:-1]
+        self.assertEqual(1, len(lines))
+
+        line = lines[0]
+
+        image_id, name, disk_format, container_format, size = \
+            [c.strip() for c in line.split()]
+        self.assertEqual('MyImage', name)
+
+        self.assertEqual('0', size, "Expected image to be 0 bytes in size, "
+                                    "but got %s. " % size)
+
+    def test_add_with_location_and_stdin(self):
+        self.cleanup()
+        self.start_servers(**self.__dict__.copy())
+
+        api_port = self.api_port
+        registry_port = self.registry_port
+
+        # 0. Verify no public images
+        cmd = "bin/glance --port=%d index" % api_port
+
+        exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        self.assertEqual('', out.strip())
+
+        # 1. Add public image
+        with tempfile.NamedTemporaryFile() as image_file:
+            image_file.write("XXX")
+            image_file.flush()
+            file_name = image_file.name
+            cmd = "bin/glance --port=%d add is_public=True name=MyImage " \
+                  "location=http://example.com < %s" % (api_port, file_name)
+            exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        self.assertTrue(out.strip().startswith('Added new image with ID:'))
+
+        # 2. Verify image added as public image
+        cmd = "bin/glance --port=%d index" % api_port
+
+        exitcode, out, err = execute(cmd)
+
+        self.assertEqual(0, exitcode)
+        lines = out.split("\n")[2:-1]
+        self.assertEqual(1, len(lines))
+
+        line = lines[0]
+
+        image_id, name, disk_format, container_format, size = \
+            [c.strip() for c in line.split()]
+        self.assertEqual('MyImage', name)
+
+        self.assertEqual('0', size, "Expected image to be 0 bytes in size, "
+                                    "but got %s. " % size)
+
     def test_add_list_delete_list(self):
         """
         We test the following:
 
             0. Verify no public images in index
-            1. Add a public image with a location attr
-               and no image data
+            1. Add a public image
             2. Check that image exists in index
             3. Delete the image
             4. Verify no longer in index
@@ -319,7 +404,8 @@ class TestBinGlance(functional.FunctionalTest):
         _add_args = [
             "name=Name1 disk_format=vhd container_format=ovf foo=bar",
             "name=Name2 disk_format=ami container_format=ami foo=bar",
-            "name=Name3 disk_format=vhd container_format=ovf foo=baz",
+            "name=Name3 disk_format=vhd container_format=ovf foo=baz "
+            "min_disk=7 min_ram=256",
         ]
 
         for i, args in enumerate(_add_args):
@@ -403,9 +489,27 @@ class TestBinGlance(functional.FunctionalTest):
 
         self.assertEqual(0, exitcode)
         image_lines = out.split("\n")[1:-1]
-        self.assertEqual(22, len(image_lines))
+        self.assertEqual(24, len(image_lines))
         self.assertTrue(image_lines[1].startswith('Id: 2'))
-        self.assertTrue(image_lines[12].startswith('Id: 1'))
+        self.assertTrue(image_lines[13].startswith('Id: 1'))
+
+        # 10. Check min_ram filter
+        cmd = "min_ram=256"
+        exitcode, out, err = execute("%s %s" % (_details_cmd, cmd))
+
+        self.assertEqual(0, exitcode)
+        image_lines = out.split("\n")[2:-1]
+        self.assertEqual(11, len(image_lines))
+        self.assertTrue(image_lines[0].startswith('Id: 3'))
+
+        # 11. Check min_disk filter
+        cmd = "min_disk=7"
+        exitcode, out, err = execute("%s %s" % (_details_cmd, cmd))
+
+        self.assertEqual(0, exitcode)
+        image_lines = out.split("\n")[2:-1]
+        self.assertEqual(11, len(image_lines))
+        self.assertTrue(image_lines[0].startswith('Id: 3'))
 
         self.stop_servers()
 
@@ -484,9 +588,9 @@ class TestBinGlance(functional.FunctionalTest):
 
         self.assertEqual(0, exitcode)
         image_lines = out.split("\n")[1:-1]
-        self.assertEqual(20, len(image_lines))
+        self.assertEqual(22, len(image_lines))
         self.assertTrue(image_lines[1].startswith('Id: 3'))
-        self.assertTrue(image_lines[11].startswith('Id: 1'))
+        self.assertTrue(image_lines[12].startswith('Id: 1'))
 
     def test_results_sorting(self):
         self.cleanup()
@@ -556,7 +660,7 @@ class TestBinGlance(functional.FunctionalTest):
 
         self.assertEqual(0, exitcode)
         image_lines = out.split("\n")[1:-1]
-        self.assertEqual(30, len(image_lines))
+        self.assertEqual(33, len(image_lines))
         self.assertTrue(image_lines[1].startswith('Id: 3'))
-        self.assertTrue(image_lines[11].startswith('Id: 2'))
-        self.assertTrue(image_lines[21].startswith('Id: 5'))
+        self.assertTrue(image_lines[12].startswith('Id: 2'))
+        self.assertTrue(image_lines[23].startswith('Id: 5'))
