@@ -33,6 +33,7 @@ from glance.common import context
 from glance.common import exception
 from glance.registry import server as rserver
 from glance.api import v1 as server
+from glance.api.middleware import version_negotiation
 import glance.store
 import glance.store.filesystem
 import glance.store.http
@@ -94,7 +95,7 @@ def stub_out_registry_and_store_server(stubs):
         def close(self):
             return True
 
-        def request(self, method, url, body=None, headers={}):
+        def request(self, method, url, body=None, headers=None):
             self.req = webob.Request.blank("/" + url.lstrip("/"))
             self.req.method = method
             if headers:
@@ -137,7 +138,10 @@ def stub_out_registry_and_store_server(stubs):
             self.req.headers[key] = value
 
         def endheaders(self):
-            pass
+            hl = [i.lower() for i in self.req.headers.keys()]
+            assert not ('content-length' in hl and
+                        'transfer-encoding' in hl), \
+                'Content-Length and Transfer-Encoding are mutually exclusive'
 
         def send(self, data):
             # send() is called during chunked-transfer encoding, and
@@ -145,7 +149,7 @@ def stub_out_registry_and_store_server(stubs):
             # only write the actual data in tests.
             self.req.body += data.split("\r\n")[1]
 
-        def request(self, method, url, body=None, headers={}):
+        def request(self, method, url, body=None, headers=None):
             self.req = webob.Request.blank("/" + url.lstrip("/"))
             self.req.method = method
             if headers:
@@ -156,11 +160,15 @@ def stub_out_registry_and_store_server(stubs):
         def getresponse(self):
             options = {'verbose': VERBOSE,
                        'debug': DEBUG,
+                       'bind_host': '0.0.0.0',
+                       'bind_port': '9999999',
                        'registry_host': '0.0.0.0',
                        'registry_port': '9191',
                        'default_store': 'file',
                        'filesystem_store_datadir': FAKE_FILESYSTEM_ROOTDIR}
-            api = context.ContextMiddleware(server.API(options), options)
+            api = version_negotiation.VersionNegotiationFilter(
+                context.ContextMiddleware(server.API(options), options),
+                options)
             res = self.req.get_response(api)
 
             # httplib.Response has a read() method...fake it out
