@@ -29,7 +29,7 @@ function process_option {
   esac
 }
 
-venv=.glance-venv
+venv=.venv
 with_venv=tools/with_venv.sh
 always_venv=0
 never_venv=0
